"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import React, { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initHighlighter = async () => {
      try {
        log('Starting highlighter initialization');
        log('Initial languages:', initialLanguages.map(l => ({
          name: l.name,
          scopeName: l.scopeName,
          patterns: l.patterns?.length
        })));
        log('Initial themes:', initialThemes.map(t => ({
          name: t.name,
          type: t.type,
          tokenColors: t.tokenColors?.length
        })));
        const engine = createJavaScriptRegexEngine({
          forgiving: true,
          cache: new Map()
        });
        log('Created JavaScript regex engine');
        const instance = await createHighlighterCore({
          langs: initialLanguages,
          themes: initialThemes,
          engine
        });
        log('Created highlighter core');

        // Verify themes loaded
        const loadedThemes = instance.getLoadedThemes();
        log('Loaded themes:', loadedThemes);
        for (const theme of loadedThemes) {
          const themeData = instance.getTheme(theme);
          log(`Theme ${theme} data:`, {
            name: themeData.name,
            type: themeData.type,
            settings: themeData.settings?.length,
            colors: Object.keys(themeData.colors || {}).length
          });
        }

        // Verify languages loaded
        const loadedLangs = instance.getLoadedLanguages();
        log('Loaded languages:', loadedLangs);

        // Test tokenization
        const testResult = instance.codeToTokensBase('const x = 1', {
          lang: 'javascript',
          theme: loadedThemes[0],
          includeExplanation: true
        });
        log('Test tokenization result:', {
          lines: testResult.length,
          tokens: testResult[0]?.map(t => ({
            content: t.content,
            color: t.color,
            explanation: t.explanation
          }))
        });
        setHighlighter(instance);
        setIsReady(true);
      } catch (err) {
        console.error('Highlighter initialization error:', err);
        setError(err instanceof Error ? err : new Error('Failed to initialize highlighter'));
      }
    };
    initHighlighter();
  }, []);
  const value = useMemo(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map