"use strict";

/* eslint-disable no-console */

import React, { memo, useCallback, useEffect, useState } from 'react';
import { ScrollView, StyleSheet, Text, View } from 'react-native';
import { useShiki } from './SyntaxContext';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const DEBUG = true;
function log(...args) {
  if (DEBUG) console.log('[SyntaxHighlighter]', ...args);
}
const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
export const SyntaxHighlighter = /*#__PURE__*/memo(({
  code,
  language,
  theme = 'github-dark',
  fontSize = 14
}) => {
  const {
    highlighter,
    isReady
  } = useShiki();
  const [tokens, setTokens] = useState([]);
  const [error, setError] = useState(null);
  const highlight = useCallback(async () => {
    if (!highlighter || !isReady) return;
    try {
      const loadedLangs = highlighter.getLoadedLanguages();
      const normalizedLang = language.toLowerCase();
      const effectiveLang = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text';
      log('Starting tokenization:', {
        lang: effectiveLang,
        theme: typeof theme === 'string' ? theme : theme.name,
        snippet: code.slice(0, 50)
      });

      // Get grammar info
      const grammar = highlighter.getLanguage(effectiveLang);
      log('Using grammar:', {
        name: grammar.name,
        // Only log properties we know exist on Grammar
        id: typeof grammar === 'object' && 'id' in grammar ? grammar.id : undefined
      });

      // Handle theme data
      const themeName = typeof theme === 'string' ? theme : theme.name;
      const themeData = highlighter.getTheme(themeName || 'default');
      log('Using theme:', {
        name: themeData.name,
        type: themeData.type,
        settingsCount: themeData.settings?.length ?? 0
      });

      // Use explicit tokenization settings
      const results = highlighter.codeToTokensBase(code, {
        lang: effectiveLang,
        theme: themeName,
        includeExplanation: true
      });
      if (results[0]?.length === 1) {
        log('WARNING: Single token per line:', {
          total: results.length,
          firstLine: results[0]
        });
      }
      log('Tokenization results:', {
        lines: results.length,
        tokenCounts: results.map(line => line.length),
        firstLineTokens: results[0]?.map(token => ({
          content: token.content,
          color: token.color,
          scopes: token.explanation?.[0]?.scopes
        }))
      });
      setTokens(results);
      setError(null);
    } catch (err) {
      const msg = err instanceof Error ? err.message : 'Failed to highlight code';
      console.error('Highlighting error:', err);
      setError(msg);
    }
  }, [code, language, theme, highlighter, isReady]);
  useEffect(() => {
    highlight();
  }, [highlight]);

  // Log render cycles
  useEffect(() => {
    if (tokens.length) {
      log('Rendering tokens:', {
        lineCount: tokens.length,
        tokensPerLine: tokens.map(line => line.length),
        sample: tokens[0]?.slice(0, 2)
      });
    }
  }, [tokens]);
  if (!isReady) {
    return /*#__PURE__*/_jsx(View, {
      style: styles.container,
      children: /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })
    });
  }
  if (error) {
    return /*#__PURE__*/_jsxs(View, {
      style: styles.container,
      children: [/*#__PURE__*/_jsx(Text, {
        style: {
          color: 'red'
        },
        children: error
      }), /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })]
    });
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    style: styles.container,
    contentContainerStyle: {
      padding: 10
    },
    children: /*#__PURE__*/_jsx(View, {
      children: tokens.map((line, i) => /*#__PURE__*/_jsx(View, {
        style: styles.line,
        children: line.map((token, j) => {
          if (i === 0 && j < 3) {
            log('Rendering token:', {
              content: token.content,
              color: token.color,
              scopes: token.explanation?.[0]?.scopes
            });
          }
          return /*#__PURE__*/_jsx(Text, {
            style: {
              color: token.color || '#e1e4e8',
              fontSize,
              ...(token.fontStyle && token.fontStyle & 1 && {
                fontStyle: 'italic'
              }),
              ...(token.fontStyle && token.fontStyle & 2 && {
                fontWeight: 'bold'
              })
            },
            children: token.content
          }, `${i}-${j}`);
        })
      }, i))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map